@@ -1,6 +1,6 @@
 package Enbld::Archivefile;
 
-use strict;
+use 5.012;
 use warnings;
 
 use Archive::Tar;
